# AutoTestModelV2GetModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**external_id** | **str, none_type** | This property is used to set autotest identifier from client system | [optional] 
**links** | [**[LinkModel], none_type**](LinkModel.md) |  | [optional] 
**project_id** | **str** | This property is used to link autotest with project | [optional] 
**name** | **str, none_type** |  | [optional] 
**namespace** | **str, none_type** |  | [optional] 
**classname** | **str, none_type** |  | [optional] 
**steps** | [**[AutoTestStepModel], none_type**](AutoTestStepModel.md) |  | [optional] 
**setup** | [**[AutoTestStepModel], none_type**](AutoTestStepModel.md) |  | [optional] 
**teardown** | [**[AutoTestStepModel], none_type**](AutoTestStepModel.md) |  | [optional] 
**global_id** | **int** |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 
**modified_date** | **datetime, none_type** |  | [optional] 
**created_by_id** | **str** |  | [optional] 
**modified_by_id** | **str, none_type** |  | [optional] 
**labels** | [**[LabelShortModel], none_type**](LabelShortModel.md) |  | [optional] 
**id** | **str** |  | [optional] 
**is_deleted** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


